==> kubernetes-model-storageclass-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/CSIDriverSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSIDriverSpecBuilder extends io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpecFluentImpl<io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpec,io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpecBuilder>{
  public CSIDriverSpecBuilder() {
    this(false);
  }
  public CSIDriverSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new CSIDriverSpec(), validationEnabled);
  }
  public CSIDriverSpecBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CSIDriverSpecBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSIDriverSpec(), validationEnabled);
  }
  public CSIDriverSpecBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpec instance) {
    this(fluent, instance, false);
  }
  public CSIDriverSpecBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAttachRequired(instance.getAttachRequired()); 
    fluent.withFsGroupPolicy(instance.getFsGroupPolicy()); 
    fluent.withPodInfoOnMount(instance.getPodInfoOnMount()); 
    fluent.withRequiresRepublish(instance.getRequiresRepublish()); 
    fluent.withStorageCapacity(instance.getStorageCapacity()); 
    fluent.withTokenRequests(instance.getTokenRequests()); 
    fluent.withVolumeLifecycleModes(instance.getVolumeLifecycleModes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSIDriverSpecBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpec instance) {
    this(instance,false);
  }
  public CSIDriverSpecBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAttachRequired(instance.getAttachRequired()); 
    this.withFsGroupPolicy(instance.getFsGroupPolicy()); 
    this.withPodInfoOnMount(instance.getPodInfoOnMount()); 
    this.withRequiresRepublish(instance.getRequiresRepublish()); 
    this.withStorageCapacity(instance.getStorageCapacity()); 
    this.withTokenRequests(instance.getTokenRequests()); 
    this.withVolumeLifecycleModes(instance.getVolumeLifecycleModes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.v1beta1.CSIDriverSpec build() {
    CSIDriverSpec buildable = new CSIDriverSpec(fluent.getAttachRequired(),fluent.getFsGroupPolicy(),fluent.getPodInfoOnMount(),fluent.getRequiresRepublish(),fluent.getStorageCapacity(),fluent.getTokenRequests(),fluent.getVolumeLifecycleModes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSIDriverSpecBuilder that = (CSIDriverSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-storageclass-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/CSIDriverSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CSIDriverSpecBuilder extends CSIDriverSpecFluentImpl<CSIDriverSpecBuilder> implements VisitableBuilder<CSIDriverSpec,CSIDriverSpecBuilder>{
  public CSIDriverSpecBuilder() {
    this(false);
  }
  public CSIDriverSpecBuilder(Boolean validationEnabled) {
    this(new CSIDriverSpec(), validationEnabled);
  }
  public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CSIDriverSpec(), validationEnabled);
  }
  public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent,CSIDriverSpec instance) {
    this(fluent, instance, false);
  }
  public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent,CSIDriverSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAttachRequired(instance.getAttachRequired()); 
    fluent.withFsGroupPolicy(instance.getFsGroupPolicy()); 
    fluent.withPodInfoOnMount(instance.getPodInfoOnMount()); 
    fluent.withRequiresRepublish(instance.getRequiresRepublish()); 
    fluent.withStorageCapacity(instance.getStorageCapacity()); 
    fluent.withTokenRequests(instance.getTokenRequests()); 
    fluent.withVolumeLifecycleModes(instance.getVolumeLifecycleModes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSIDriverSpecBuilder(CSIDriverSpec instance) {
    this(instance,false);
  }
  public CSIDriverSpecBuilder(CSIDriverSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAttachRequired(instance.getAttachRequired()); 
    this.withFsGroupPolicy(instance.getFsGroupPolicy()); 
    this.withPodInfoOnMount(instance.getPodInfoOnMount()); 
    this.withRequiresRepublish(instance.getRequiresRepublish()); 
    this.withStorageCapacity(instance.getStorageCapacity()); 
    this.withTokenRequests(instance.getTokenRequests()); 
    this.withVolumeLifecycleModes(instance.getVolumeLifecycleModes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CSIDriverSpecFluent<?> fluent;
  Boolean validationEnabled;
  public CSIDriverSpec build() {
    CSIDriverSpec buildable = new CSIDriverSpec(fluent.getAttachRequired(),fluent.getFsGroupPolicy(),fluent.getPodInfoOnMount(),fluent.getRequiresRepublish(),fluent.getStorageCapacity(),fluent.getTokenRequests(),fluent.getVolumeLifecycleModes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
